@@ -1,7 +1,7 @@
-#!/usr/bin/env python2
+#!/usr/bin/env python3
 
 # Circle Popper
-# Written in 2012, 2013 by Julian Marchant <onpon4@riseup.net>
+# Written in 2012, 2013, 2014 by Julian Marchant <onpon4@riseup.net>
 #
 # To the extent possible under law, the author(s) have dedicated all
 # copyright and related and neighboring rights to this software to the
@@ -12,19 +12,6 @@
 # along with this software. If not, see
 # <http://creativecommons.org/publicdomain/zero/1.0/>.
 
-
-"""Stellar Game Engine example
-
-This is a simple example of a possible game in Stellar Game Engine, just
-to give a general idea of how it will be used.
-
-"""
-
-from __future__ import division
-from __future__ import absolute_import
-from __future__ import print_function
-from __future__ import unicode_literals
-
 import sge
 import random
 
@@ -49,25 +36,24 @@ class Game(sge.Game):
 class Circle(sge.StellarClass):
 
     def __init__(self, x, y):
-        super(Circle, self).__init__(x, y, 5, sprite='circle',
-                                     collision_precise=True)
+        super().__init__(x, y, 5, sprite='circle', collision_precise=True)
 
     def event_create(self):
         self.image_alpha = 200
-        if self.collides(sge.game.mouse):
+        if self.collision(sge.game.mouse):
             self.image_blend = '#ff0000'
         else:
             self.image_blend = 'blue'
 
     def event_mouse_move(self, x, y):
-        if self.collides(sge.game.mouse):
+        if self.collision(sge.game.mouse):
             self.image_blend = "red"
         else:
             self.image_blend = (0, 0, 255)
 
     def event_mouse_button_press(self, button):
         if button == 'left':
-            if self.collides(sge.game.mouse):
+            if self.collision(sge.game.mouse):
                 self.destroy()
 
     def event_destroy(self):
@@ -81,7 +67,7 @@ class Circle(sge.StellarClass):
 class CirclePop(sge.StellarClass):
 
     def __init__(self, x, y):
-        super(CirclePop, self).__init__(x, y, 5, sprite='circle_pop')
+        super().__init__(x, y, 5, sprite='circle_pop')
 
     def event_animation_end(self):
         self.destroy()
@@ -97,7 +83,7 @@ class Room(sge.Room):
     def event_room_start(self):
         glob.music.play(loops=None)
 
-    def event_step(self, time_passed):
+    def event_step(self, time_passed, delta_mult):
         text = "I am amazing text!\n\nYaaaaaaaaaaay~!"
         self.project_text(glob.font, text, 320, 0, 3, color="black",
                           halign=sge.ALIGN_CENTER)
