@@ -268,8 +268,6 @@ class Game:
                 except pygame.error:
                     continue
 
-                print('This shouldn\'t show. Remove me.')
-
     def __init__(self, width=640, height=480, fullscreen=False, scale=0,
                  scale_proportional=True, scale_smooth=False, fps=60,
                  delta=False, delta_min=15, grab_input=False,
@@ -608,8 +606,8 @@ class Game:
                             int(1000 / real_time_passed), delta_mult)
 
                 # Step events
-                self.event_step(real_time_passed)
-                self.current_room.event_step(real_time_passed)
+                self.event_step(real_time_passed, delta_mult)
+                self.current_room.event_step(real_time_passed, delta_mult)
 
                 # Update background layers
                 for i in self.background_layers:
@@ -618,11 +616,11 @@ class Game:
                 # Update objects (including mouse)
                 for obj in self.current_room.objects:
                     if obj.active:
-                        obj.event_begin_step(real_time_passed)
+                        obj.event_begin_step(real_time_passed, delta_mult)
                         obj._update(time_passed, delta_mult)
-                        obj.event_step(real_time_passed)
+                        obj.event_step(real_time_passed, delta_mult)
                     else:
-                        obj.event_inactive_step(real_time_passed)
+                        obj.event_inactive_step(real_time_passed, delta_mult)
 
                 # Set objects' colliders
                 room = self.current_room
@@ -651,31 +649,13 @@ class Game:
                 # End step event
                 for obj in self.current_room.objects:
                     if obj.active:
-                        obj.event_end_step(real_time_passed)
+                        obj.event_end_step(real_time_passed, delta_mult)
                     else:
-                        obj.event_inactive_end_step(real_time_passed)
+                        obj.event_inactive_end_step(real_time_passed,
+                                                    delta_mult)
 
                 # Music control
-                if self._music is not None:
-                    if pygame.mixer.music.get_busy():
-                        time_played = pygame.mixer.music.get_pos()
-                        fade_time = self._music._fade_time
-                        timeout = self._music._timeout
-
-                        if fade_time:
-                            real_volume = self._music.volume / 100
-                            if time_played < fade_time:
-                                volume = real_volume * time_played / fade_time
-                                pygame.mixer.music.set_volume(volume)
-                            else:
-                                pygame.mixer.music.set_volume(real_volume)
-
-                        if timeout and time_played >= timeout:
-                            self._music.stop()
-                            
-                    elif self._music_queue:
-                        music = self._music_queue.pop(0)
-                        music[0].play(*music[1:])
+                self._handle_music()
 
                 if numviews != len(self.current_room.views):
                     numviews = len(self.current_room.views)
@@ -918,6 +898,9 @@ class Game:
 
             # Time management
             self._clock.tick(self.fps)
+
+            # Music control
+            self._handle_music()
             
             # Redraw
             self._window.blit(background, (0, 0))
@@ -1121,7 +1104,7 @@ class Game:
         """
         pass
 
-    def event_step(self, time_passed):
+    def event_step(self, time_passed, delta_mult):
         """Global step event.
 
         Called once each frame.
@@ -1130,6 +1113,9 @@ class Game:
 
         - ``time_passed`` -- The number of milliseconds that have passed
           during the last frame.
+        - ``delta_mult`` -- What speed and movement should be multiplied
+          by this frame due to delta timing.  If :attr:`delta` is
+          :const:`False`, this is always ``1``.
 
         """
         pass
@@ -1786,3 +1772,26 @@ class Game:
 
         for i in range(old_num_channels, new_num_channels):
             self._available_channels.append(pygame.mixer.Channel(i))
+
+    def _handle_music(self):
+        # Call each frame to control the music playback.
+        if self._music is not None:
+            if pygame.mixer.music.get_busy():
+                time_played = pygame.mixer.music.get_pos()
+                fade_time = self._music._fade_time
+                timeout = self._music._timeout
+
+                if fade_time:
+                    real_volume = self._music.volume / 100
+                    if time_played < fade_time:
+                        volume = real_volume * time_played / fade_time
+                        pygame.mixer.music.set_volume(volume)
+                    else:
+                        pygame.mixer.music.set_volume(real_volume)
+
+                if timeout and time_played >= timeout:
+                    self._music.stop()
+                    
+            elif self._music_queue:
+                music = self._music_queue.pop(0)
+                music[0].play(*music[1:])
