@@ -1,4 +1,4 @@
-# Copyright (C) 2012, 2013 Julian Marchant <onpon4@riseup.net>
+# Copyright (C) 2012, 2013, 2014 Julian Marchant <onpon4@riseup.net>
 # 
 # This file is part of the Pygame SGE.
 # 
@@ -15,11 +15,6 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with the Pygame SGE.  If not, see <http://www.gnu.org/licenses/>.
 
-from __future__ import division
-from __future__ import absolute_import
-from __future__ import print_function
-from __future__ import unicode_literals
-
 import os
 
 import pygame
@@ -27,12 +22,12 @@ import pygame
 import sge
 
 
-__all__ = [u'Music']
+__all__ = ['Music']
 
 
-class Music(object):
+class Music:
 
-    u"""Music handling class.
+    """Music handling class.
 
     This class stores and plays music.  Music is very similar to sound
     effects, but only one music file can be played at a time, and it is
@@ -107,7 +102,7 @@ class Music(object):
             return 0
 
     def __init__(self, fname, ID=None, volume=100):
-        u"""Constructor method.
+        """Constructor method.
 
         Arguments:
 
@@ -141,10 +136,10 @@ class Music(object):
                     break
 
             if self._full_fname is None:
-                print(u"Directories searched:")
+                print("Directories searched:")
                 for d in sge.music_directories:
                     print(os.path.normpath(os.path.abspath(d)))
-                msg = u'File "{0}" not found.'.format(self.fname)
+                msg = 'File "{}" not found.'.format(self.fname)
                 raise IOError(msg)
 
             if ID is not None:
@@ -152,7 +147,7 @@ class Music(object):
             else:
                 self.id = os.path.splitext(os.path.basename(self.fname))[0]
                 while self.id in sge.game.music:
-                    self.id += u"_"
+                    self.id += "_"
         else:
             self._full_fname = None
 
@@ -168,7 +163,7 @@ class Music(object):
         sge.game.music[self.id] = self
 
     def play(self, start=0, loops=1, maxtime=None, fade_time=None):
-        u"""Play the music.
+        """Play the music.
 
         Arguments:
 
@@ -193,7 +188,7 @@ class Music(object):
             if self._fade_time is not None and self._fade_time > 0:
                 pygame.mixer.music.set_volume(0)
 
-            if self.fname.lower().endswith(u".mod"):
+            if self.fname.lower().endswith(".mod"):
                 # MOD music is handled differently in Pygame: it uses
                 # the pattern order number rather than the time to
                 # indicate the start time.
@@ -207,7 +202,7 @@ class Music(object):
                     pygame.mixer.music.play(loops)
 
     def queue(self, start=0, loops=1, maxtime=None, fade_time=None):
-        u"""Queue the music for playback.
+        """Queue the music for playback.
 
         This will cause the music to be added to a list of music to play
         in order, after the previous music has finished playing.
@@ -218,9 +213,16 @@ class Music(object):
         """
         sge.game._music_queue.append((self, start, loops, maxtime, fade_time))
 
+    def destroy(self):
+        """Destroy the music."""
+        if self.playing:
+            self.stop()
+
+        del sge.game.music[self.id]
+
     @staticmethod
     def stop(fade_time=None):
-        u"""Stop the currently playing music.
+        """Stop the currently playing music.
 
         See the documentation for :meth:`sge.Sound.stop` for more
         information.
@@ -233,15 +235,15 @@ class Music(object):
 
     @staticmethod
     def pause():
-        u"""Pause playback of the currently playing music."""
+        """Pause playback of the currently playing music."""
         pygame.mixer.music.pause()
 
     @staticmethod
     def unpause():
-        u"""Resume playback of the currently playing music if paused."""
+        """Resume playback of the currently playing music if paused."""
         pygame.mixer.music.unpause()
 
     @staticmethod
     def clear_queue():
-        u"""Clear the music queue."""
+        """Clear the music queue."""
         sge.game._music_queue = []
