@@ -131,6 +131,20 @@ class StellarClass(object):
        The height of the bounding box in pixels.  If set to
        :const:`None`, the value recommended by the sprite is used.
 
+    .. attribute:: regulate_origin
+
+       If set to :const:`True`, the origin is automatically adjusted to
+       be the location of the pixel recommended by the sprite after
+       transformation.  This will cause rotation to be about the origin
+       rather than being about the center of the image.
+
+       .. note::
+
+          The value of this attribute has no effect on the bounding box.
+          If you wish for the bounding box to be adjusted as well, you
+          must do so manually.  As an alternative, you may want to
+          consider using precise collision detection instead.
+
     .. attribute:: collision_ellipse
 
        Whether or not an ellipse (rather than a rectangle) should be
@@ -185,6 +199,18 @@ class StellarClass(object):
        The animation frame currently being displayed, with ``0`` being
        the first one.
 
+    .. attribute:: image_origin_x
+
+       The horizontal location of the origin relative to the left edge
+       of the images.  If set to :const:`None`, the value recommended by
+       the sprite is used.
+
+    .. attribute:: image_origin_y
+
+       The vertical location of the origin relative to the top edge of
+       the images.  If set to :const:`None`, the value recommended by
+       the sprite is used.
+
     .. attribute:: image_fps
 
        The animation rate in frames per second.  If set to
@@ -208,6 +234,10 @@ class StellarClass(object):
        The rotation of the sprite in degrees, with rotation in a
        positive direction being counter-clockwise.
 
+       If :attr:`regulate_origin` is :const:`True`, the image is rotated
+       about the origin.  Otherwise, the image is rotated about its
+       center.
+
     .. attribute:: image_alpha
 
        The alpha value applied to the entire image, where ``255`` is the
@@ -223,6 +253,12 @@ class StellarClass(object):
 
        The unique identifier for this object.  (Read-only)
 
+    .. attribute:: mask
+
+       The current mask used for non-rectangular collision detection.
+       See the documentation for :func:`sge.collision.masks_collide` for
+       more information.  (Read-only)
+
     .. attribute:: xstart
 
        The initial value of :attr:`x` when the object was created.
@@ -243,6 +279,14 @@ class StellarClass(object):
        The value of :attr:`y` at the end of the previous frame.
        (Read-only)
 
+    .. attribute:: mask_x
+
+       The horizontal location of the mask in the room.  (Read-only)
+
+    .. attribute:: mask_y
+
+       The vertical location of the mask in the room.  (Read-only)
+
     """
 
     @property
@@ -252,6 +296,7 @@ class StellarClass(object):
     @x.setter
     def x(self, value):
         self._x = value
+        self._update_collision_areas()
 
         # Cause the Pygame sprite to make itself dirty
         self._pygame_sprite.rect = pygame.Rect(0, 0, 1, 1)
@@ -263,6 +308,7 @@ class StellarClass(object):
     @y.setter
     def y(self, value):
         self._y = value
+        self._update_collision_areas()
 
         # Cause the Pygame sprite to make itself dirty
         self._pygame_sprite.rect = pygame.Rect(0, 0, 1, 1)
@@ -297,7 +343,8 @@ class StellarClass(object):
         else:
             self._sprite = sge.game.sprites[value]
 
-        self.image_index = self.image_index % len(self._sprite._images)
+        if self._sprite is not None:
+            self.image_index = self.image_index % len(self._sprite._images)
 
     @property
     def detects_collisions(self):
@@ -319,6 +366,42 @@ class StellarClass(object):
             if position is not None:
                 del sge.game._colliders[position]
 
+    @property
+    def bbox_x(self):
+        return self._bbox_x
+
+    @bbox_x.setter
+    def bbox_x(self, value):
+        self._bbox_x = value
+        self._update_collision_areas()
+
+    @property
+    def bbox_y(self):
+        return self._bbox_y
+
+    @bbox_y.setter
+    def bbox_y(self, value):
+        self._bbox_y = value
+        self._update_collision_areas()
+
+    @property
+    def bbox_width(self):
+        return self._bbox_width
+
+    @bbox_width.setter
+    def bbox_width(self, value):
+        self._bbox_width = value
+        self._update_collision_areas()
+
+    @property
+    def bbox_height(self):
+        return self._bbox_height
+
+    @bbox_height.setter
+    def bbox_height(self, value):
+        self._bbox_height = value
+        self._update_collision_areas()
+
     @property
     def collision_ellipse(self):
         return self._collision_ellipse
@@ -421,6 +504,52 @@ class StellarClass(object):
         else:
             self._image_index = 0
 
+    @property
+    def image_origin_x(self):
+        if self.regulate_origin and self.sprite is not None:
+            id_ = (self.sprite.id, self.sprite.width, self.sprite.height,
+                   self.sprite.origin_x, self.sprite.origin_y,
+                   self.image_xscale, self.image_yscale, self.image_rotation)
+
+            if id_ not in self._origins_x:
+                x_offset, y_offset = self._get_origin_offset()
+                self._origins_x[id_] = self.sprite.origin_x + x_offset
+                self._origins_y[id_] = self.sprite.origin_y + y_offset
+
+            self._image_origin_x = self._origins_x[id_]
+
+        if self._image_origin_x is None:
+            return self.sprite.origin_x if self.sprite is not None else 0
+        else:
+            return self._image_origin_x
+
+    @image_origin_x.setter
+    def image_origin_x(self, value):
+        self._image_origin_x = value
+
+    @property
+    def image_origin_y(self):
+        if self.regulate_origin and self.sprite is not None:
+            id_ = (self.sprite.id, self.sprite.width, self.sprite.height,
+                   self.sprite.origin_x, self.sprite.origin_y,
+                   self.image_xscale, self.image_yscale, self.image_rotation)
+
+            if id_ not in self._origins_y:
+                x_offset, y_offset = self._get_origin_offset()
+                self._origins_x[id_] = self.sprite.origin_x + x_offset
+                self._origins_y[id_] = self.sprite.origin_y + y_offset
+
+            self._image_origin_y = self._origins_y[id_]
+
+        if self._image_origin_y is None:
+            return self.sprite.origin_y if self.sprite is not None else 0
+        else:
+            return self._image_origin_y
+
+    @image_origin_y.setter
+    def image_origin_y(self, value):
+        self._image_origin_y = value
+
     @property
     def image_fps(self):
         return self._fps
@@ -452,13 +581,94 @@ class StellarClass(object):
 
         self.image_fps = value * sge.game.fps
 
+    @property
+    def mask(self):
+        if self.collision_precise:
+            id_ = ("precise", self.sprite.id, self.sprite.width,
+                   self.sprite.height, self.image_index, self.image_xscale,
+                   self.image_yscale, self.image_rotation)
+        else:
+            id_ = (self.collision_ellipse, self.bbox_x, self.bbox_y,
+                   self.bbox_width, self.bbox_height, self.image_xscale,
+                   self.image_yscale)
+
+        if id_ in self._masks:
+            return self._masks[id_]
+        else:
+            if self.collision_precise:
+                # Mask based on opacity of the current image.
+                mask = self.sprite._get_precise_mask(
+                    self.image_index, self.image_xscale, self.image_yscale,
+                    self.image_rotation)
+            elif self.collision_ellipse:
+                # Elliptical mask based on bounding box.
+                mask = [[False for y in xrange(self.bbox_height)]
+                        for x in xrange(self.bbox_width)]
+                a = len(mask) / 2
+                b = len(mask[0]) / 2 if mask else 0
+
+                for x in xrange(len(mask)):
+                    for y in xrange(len(mask[x])):
+                        if ((x - a) / a) ** 2 + ((y - b) / b) ** 2 <= 1:
+                            mask[x][y] = True
+            else:
+                # Mask is all pixels in the bounding box.
+                mask = [[True for y in xrange(self.bbox_height)]
+                        for x in xrange(self.bbox_width)]
+
+            self._masks[id_] = mask
+            return mask
+
+    @property
+    def mask_x(self):
+        if self.collision_precise:
+            id_ = (self.sprite.id, self.sprite.width, self.sprite.height,
+                   self.image_origin_x, self.image_origin_y, self.image_xscale,
+                   self.image_yscale, self.image_rotation)
+            if id_ in self._masks_x_offset:
+                offset = self._masks_x_offset[id_]
+                return self.x - (self.image_origin_x + offset)
+            elif self.image_rotation % 180:
+                width = self._get_image_width()
+                normal_width = self._get_normal_image_width()
+                offset = (width - normal_width) / 2
+                self._masks_x_offset[id_] = offset
+                return self.x - (self.image_origin_x + offset)
+            else:
+                self._masks_x_offset[id_] = 0
+                return self.x - self.image_origin_x
+        else:
+            return self.bbox_left
+
+    @property
+    def mask_y(self):
+        if self.collision_precise:
+            id_ = (self.sprite.id, self.sprite.width, self.sprite.height,
+                   self.image_origin_x, self.image_origin_y, self.image_xscale,
+                   self.image_yscale, self.image_rotation)
+            if id_ in self._masks_y_offset:
+                offset = self._masks_y_offset[id_]
+                return self.y - (self.image_origin_y + offset)
+            elif self.image_rotation % 180:
+                height = self._get_image_height()
+                normal_height = self._get_normal_image_height()
+                offset = (height - normal_height) / 2
+                self._masks_y_offset[id_] = offset
+                return self.y - (self.image_origin_y + offset)
+            else:
+                self._masks_y_offset[id_] = 0
+                return self.y - self.image_origin_y
+        else:
+            return self.bbox_top
+
     def __init__(self, x, y, z=0, ID=None, sprite=None, visible=True,
                  active=True, detects_collisions=True, bbox_x=None,
                  bbox_y=None, bbox_width=None, bbox_height=None,
-                 collision_ellipse=False, collision_precise=False,
-                 xvelocity=0, yvelocity=0, image_index=0, image_fps=None,
-                 image_xscale=1, image_yscale=1, image_rotation=0,
-                 image_alpha=255, image_blend=None):
+                 regulate_origin=False, collision_ellipse=False,
+                 collision_precise=False, xvelocity=0, yvelocity=0,
+                 image_index=0, image_origin_x=None, image_origin_y=None,
+                 image_fps=None, image_xscale=1, image_yscale=1,
+                 image_rotation=0, image_alpha=255, image_blend=None):
         """Constructor method.
 
         Arguments:
@@ -493,12 +703,13 @@ class StellarClass(object):
             sprite_bbox_y = 0
             sprite_bbox_width = 1
             sprite_bbox_height = 1
-        self.bbox_x = bbox_x if bbox_x is not None else sprite_bbox_x
-        self.bbox_y = bbox_y if bbox_y is not None else sprite_bbox_y
-        self.bbox_width = (bbox_width if bbox_width is not None else
-                           sprite_bbox_width)
-        self.bbox_height = (bbox_height if bbox_height is not None else
-                            sprite_bbox_height)
+        self._bbox_x = bbox_x if bbox_x is not None else sprite_bbox_x
+        self._bbox_y = bbox_y if bbox_y is not None else sprite_bbox_y
+        self._bbox_width = (bbox_width if bbox_width is not None else
+                            sprite_bbox_width)
+        self._bbox_height = (bbox_height if bbox_height is not None else
+                             sprite_bbox_height)
+        self.regulate_origin = regulate_origin
         self._collision_ellipse = collision_ellipse
         self._collision_precise = collision_precise
         self._collision_areas = []
@@ -524,12 +735,19 @@ class StellarClass(object):
         self.xvelocity = xvelocity
         self.yvelocity = yvelocity
         self._anim_count = 0
+        self._origins_x = {}
+        self._origins_y = {}
+        self.image_origin_x = image_origin_x
+        self.image_origin_y = image_origin_y
         self.image_fps = image_fps
         self.image_xscale = image_xscale
         self.image_yscale = image_yscale
         self.image_rotation = image_rotation
         self.image_alpha = image_alpha
         self.image_blend = image_blend
+        self._masks = {}
+        self._masks_x_offset = {}
+        self._masks_y_offset = {}
 
         self._alarms = {}
 
@@ -540,8 +758,6 @@ class StellarClass(object):
         else:
             self._pygame_sprite = _FakePygameSprite(self)
 
-        self._set_mask()
-
         self.z = z
 
         self._start_x = self.x
@@ -557,14 +773,21 @@ class StellarClass(object):
         self._start_collision_ellipse = self.collision_ellipse
         self._start_collision_precise = self.collision_precise
 
-    def collides(self, other, x=None, y=None):
-        """Return whether or not this object collides with another.
+    def collision(self, other=None, x=None, y=None):
+        """Return a list of objects colliding with this object.
 
         Arguments:
 
-        - ``other`` -- The object to check for a collision with, or the
-          unique identifier of said object.  ``other`` can also be a
-          class to check for collisions with.
+        - ``other`` -- What to check for collisions with.  Can be one of
+          the following:
+
+          - A :class:`sge.StellarClass` object.
+          - The unique identifier of a :class:`sge.StellarClass` object.
+          - A list of :class:`sge.StellarClass` objects and/or unique
+            identifiers of :class:`sge.StellarClass` objects.
+          - A class derived from :class:`sge.StellarClass`.
+          - :const:`None`: Check for collisions with all objects.
+
         - ``x`` -- The horizontal position to pretend this object is at
           for the purpose of the collision detection.  If set to
           :const:`None`, :attr:`x` will be used.
@@ -573,18 +796,37 @@ class StellarClass(object):
           :const:`None`, :attr:`y` will be used.
 
         """
-        if isinstance(other, StellarClass):
-            others = [other]
-        elif other in sge.game.current_room.objects_by_class:
-            others = []
-            for obj in sge.game.current_room.objects_by_class[other]:
-                if obj.detects_collisions:
-                    others.append(obj)
-        else:
-            others = []
-            for ref in sge.game._colliders:
-                if isinstance(ref(), other):
-                    others.append(ref())
+        room = sge.game.current_room
+        others = []
+        collisions = []
+
+        for area in self._collision_areas:
+            if area is not None:
+                i, j = area
+                room_area = room._collision_areas[i][j]
+            else:
+                room_area = room._collision_area_void
+
+            for ref in room_area:
+                obj = ref()
+                if obj is not None and obj is not self:
+                    if other is None:
+                        others.append(obj)
+                    elif isinstance(other, StellarClass):
+                        if obj is other:
+                            others.append(obj)
+                    elif isinstance(other, (list, tuple)):
+                        if obj in other:
+                            others.append(obj)
+                    elif other in sge.game.objects:
+                        if obj is sge.game.objects[other]:
+                            others.append(obj)
+                    else:
+                        try:
+                            if isinstance(obj, other):
+                                others.append(obj)
+                        except TypeError:
+                            pass
 
         # Change x and y to be offset values; these are easier to use.
         if x is not None:
@@ -601,59 +843,19 @@ class StellarClass(object):
             if (self.collision_precise or self.collision_ellipse or
                     other.collision_precise or other.collision_ellipse):
                 # Use masks.
-                self._set_mask()
-                other._set_mask()
-
-                if self._hitmask and other._hitmask:
-                    self_rect = pygame.Rect(round(self.bbox_left + x),
-                                            round(self.bbox_top + y),
-                                            len(self._hitmask),
-                                            len(self._hitmask[0]))
-                    other_rect = pygame.Rect(round(other.bbox_left),
-                                             round(other.bbox_top),
-                                             len(other._hitmask),
-                                             len(other._hitmask[0]))
-
-                    if self.sprite is not None:
-                        # Offset for rotation
-                        w, h = self.sprite._get_image(
-                            self.image_index, self.image_xscale,
-                            self.image_yscale, self.image_rotation).get_size()
-
-                        nw, nh = self.sprite._get_image(
-                            self.image_index, self.image_xscale,
-                            self.image_yscale).get_size()
-
-                        offset = _get_rotation_offset(
-                            self.sprite.origin_x, self.sprite.origin_y,
-                            self.image_rotation, w, h, nw, nh)
-
-                        self_rect.left -= offset[0] // sge.game._xscale
-                        self_rect.top -= offset[1] // sge.game._yscale
-
-                    collide_rect = self_rect.clip(other_rect)
-                    self_xoffset = collide_rect.left - self_rect.left
-                    self_yoffset = collide_rect.top - self_rect.top
-                    other_xoffset = collide_rect.left - other_rect.left
-                    other_yoffset = collide_rect.top - other_rect.top
-
-                    for a in xrange(collide_rect.w):
-                        for b in xrange(collide_rect.h):
-                            if (self._hitmask[
-                                    a + self_xoffset][b + self_yoffset] and
-                                other._hitmask[
-                                    a + other_xoffset][b + other_yoffset]):
-                                return True
-                        
+                if sge.collision.masks_collide(
+                        self.mask_x + x, self.mask_y + y, self.mask,
+                        other.mask_x, other.mask_y, other.mask):
+                    collisions.append(other)
             else:
                 # Use bounding boxes.
-                if (self.bbox_left + x < other.bbox_right and
-                        self.bbox_right + x > other.bbox_left and
-                        self.bbox_top + y < other.bbox_bottom and
-                        self.bbox_bottom + y > other.bbox_top):
-                    return True
+                if sge.collision.rectangles_collide(
+                        self.bbox_left + x, self.bbox_top + y, self.bbox_width,
+                        self.bbox_height, other.bbox_left, other.bbox_top,
+                        other.bbox_width, other.bbox_height):
+                    collisions.append(other)
 
-        return False
+        return collisions
 
     def set_alarm(self, alarm_id, value):
         """Set an alarm.
@@ -720,7 +922,7 @@ class StellarClass(object):
         """Destroy event."""
         pass
 
-    def event_begin_step(self, time_passed):
+    def event_begin_step(self, time_passed, delta_mult):
         """Begin step event.
 
         This event is executed each frame before automatic updates to
@@ -732,14 +934,15 @@ class StellarClass(object):
         .. note::
 
            Automatic updates, the only occurances between this event and
-           :meth:`sge.StellarClass.event_step`, do not occur, so there
-           is no need for an "inactive" variant of this event.  Use
-           :meth:`sge.StellarClass.event_inactive_step` instead.
+           :meth:`sge.StellarClass.event_step`, do not occur unless the
+           object is active, so there is no "inactive" variant of this
+           event.  Use :meth:`sge.StellarClass.event_inactive_step`
+           instead.
 
         """
         pass
 
-    def event_step(self, time_passed):
+    def event_step(self, time_passed, delta_mult):
         """Step event.
 
         This event is executed each frame after automatic updates to
@@ -752,7 +955,7 @@ class StellarClass(object):
         """
         pass
 
-    def event_end_step(self, time_passed):
+    def event_end_step(self, time_passed, delta_mult):
         """Step event.
 
         This event is executed each frame after automatic updates to
@@ -880,6 +1083,26 @@ class StellarClass(object):
         """
         pass
 
+    def event_update_position(self, delta_mult):
+        """Update position event.
+
+        Called when it's time to update the position of the object.
+        This method handles this functionality, so defining this will
+        override the default behavior and allow you to handle the speed
+        variables in a special way.
+
+        The default behavior of this method is::
+
+            self.x += self.xvelocity * delta_mult
+            self.y += self.yvelocity * delta_mult
+
+        See the documentation for :meth:`sge.Game.event_step` for more
+        information.
+
+        """
+        self.x += self.xvelocity * delta_mult
+        self.y += self.yvelocity * delta_mult
+
     def event_collision(self, other):
         """Default collision event.
 
@@ -959,7 +1182,7 @@ class StellarClass(object):
         """
         self.event_collision(other)
 
-    def event_inactive_step(self, time_passed):
+    def event_inactive_step(self, time_passed, delta_mult):
         """Step event when this object is inactive.
 
         See the documentation for :meth:`sge.StellarClass.event_step`
@@ -969,7 +1192,7 @@ class StellarClass(object):
         """
         pass
 
-    def event_inactive_end_step(self, time_passed):
+    def event_inactive_end_step(self, time_passed, delta_mult):
         """End step event when this object is inactive.
 
         See the documentation for
@@ -1213,27 +1436,22 @@ class StellarClass(object):
                 self.event_alarm(a)
 
         # Movement
-        if self.xvelocity or self.yvelocity:
-            if self.id != "mouse":
-                self.x += self.xvelocity * delta_mult
-                self.y += self.yvelocity * delta_mult
+        if self.id != "mouse":
+            self.event_update_position(delta_mult)
 
+        self._update_collision_areas()
+
+    def _update_collision_areas(self):
         room = sge.game.current_room
-        area_size = room._collision_area_size
-        areas_x_start = int(self.bbox_left / area_size)
-        areas_x_num = int(math.ceil(self.bbox_width / area_size) + 1)
-        areas_y_start = int(self.bbox_top / area_size)
-        areas_y_num = int(math.ceil(self.bbox_height / area_size) + 1)
 
-        my_areas = []
-        for i in xrange(areas_x_start, areas_x_start + areas_x_num):
-            for j in xrange(areas_y_start, areas_y_start + areas_y_num):
-                if (i >= 0 and j >= 0 and room._collision_areas and
-                        i < len(room._collision_areas) and
-                        j < len(room._collision_areas[0])):
-                    my_areas.append((i, j))
-                elif None not in my_areas:
-                    my_areas.append(None)
+        if self.collision_precise:
+            my_areas = sge.collision._get_rectangle_collision_areas(
+                self.mask_x, self.mask_y, len(self.mask),
+                len(self.mask[0]) if self.mask else 0)
+        else:
+            my_areas = sge.collision._get_rectangle_collision_areas(
+                self.bbox_left, self.bbox_top, self.bbox_width,
+                self.bbox_height)
 
         for area in self._collision_areas:
             if area not in my_areas:
@@ -1271,7 +1489,7 @@ class StellarClass(object):
                     del other._colliders[i]
                     break
 
-            if self.collides(other):
+            if self.collision(other):
                 self_prev_bbox_left = self.xprevious + self.bbox_x
                 self_prev_bbox_right = self_prev_bbox_left + self.bbox_width
                 self_prev_bbox_top = self.yprevious + self.bbox_y
@@ -1313,27 +1531,66 @@ class StellarClass(object):
                     self.event_collision(other)
                     other.event_collision(self)
 
-    def _set_mask(self):
-        # Properly set the hit mask based on the collision settings.
-        if self.collision_precise:
-            # Mask based on opacity of the current image.
-            self._hitmask = self.sprite._get_precise_mask(
-                self.image_index, self.image_xscale, self.image_yscale,
-                self.image_rotation)
-        elif self.collision_ellipse:
-            # Elliptical mask based on bounding box.
-            self._hitmask = [[False for y in xrange(self.bbox_height)]
-                             for x in xrange(self.bbox_width)]
-            a = len(self._hitmask) / 2
-            b = len(self._hitmask[0]) / 2
-            for x in xrange(len(self._hitmask)):
-                for y in xrange(len(self._hitmask[x])):
-                    if ((x - a) / a) ** 2 + ((y - b) / b) ** 2 <= 1:
-                        self._hitmask[x][y] = True
-        else:
-            # Mask is all pixels in the bounding box.
-            self._hitmask = [[True for y in xrange(self.bbox_height)]
-                             for x in xrange(self.bbox_width)]
+    def _get_image_width(self):
+        # Get the width of the sprite when scaled rotated.
+        return int(self.sprite._get_image(
+            self.image_index, self.image_xscale, self.image_yscale,
+            self.image_rotation).get_width() / sge.game._xscale)
+
+    def _get_normal_image_width(self):
+        # Get the width of the sprite without scaling and rotation.
+        return int(self.sprite._get_image(
+            self.image_index, self.image_xscale,
+            self.image_yscale).get_width() / sge.game._xscale)
+
+    def _get_image_height(self):
+        # Get the height of the sprite when scaled rotated.
+        return int(self.sprite._get_image(
+            self.image_index, self.image_xscale, self.image_yscale,
+            self.image_rotation).get_height() / sge.game._xscale)
+
+    def _get_normal_image_height(self):
+        # Get the height of the sprite without scaling and rotation.
+        return int(self.sprite._get_image(
+            self.image_index, self.image_xscale,
+            self.image_yscale).get_height() / sge.game._xscale)
+
+    def _get_origin_offset(self):
+        # Return the amount to offset the origin as (x, y).
+        new_origin_x = self.sprite.origin_x
+        new_origin_y = self.sprite.origin_y
+
+        width = self._get_image_width() / abs(self.image_xscale)
+        height = self._get_image_height() / abs(self.image_yscale)
+        normal_width = self._get_normal_image_width() / abs(self.image_xscale)
+        normal_height = self._get_normal_image_height() / abs(self.image_yscale)
+
+        if self.image_rotation % 360:
+            center_x = normal_width / 2
+            center_y = normal_height / 2
+            c_origin_x = new_origin_x - center_x
+            c_origin_y = new_origin_y - center_y
+            start_angle = math.atan2(-c_origin_y, c_origin_x)
+            radius = math.hypot(c_origin_x, c_origin_y)
+            new_angle = start_angle + math.radians(self.image_rotation)
+            new_c_origin_x = radius * math.cos(new_angle)
+            new_c_origin_y = -(radius * math.sin(new_angle))
+            new_origin_x = new_c_origin_x + center_x
+            new_origin_y = new_c_origin_y + center_y
+
+        if self.image_xscale < 0:
+            new_origin_x = width - new_origin_x
+
+        if self.image_yscale < 0:
+            new_origin_y = height - new_origin_y
+
+        new_origin_x *= abs(self.image_xscale)
+        new_origin_y *= abs(self.image_yscale)
+
+        x_offset = new_origin_x - self.sprite.origin_x
+        y_offset = new_origin_y - self.sprite.origin_y
+
+        return (x_offset, y_offset)
 
     def _set_speed(self):
         # Set the speed and move direction based on xvelocity and
@@ -1493,6 +1750,7 @@ class Mouse(StellarClass):
     def _update(self, time_passed, delta_mult):
         self.update_speed(time_passed)
         super(Mouse, self)._update(time_passed, delta_mult)
+        self._update_collision_areas()
 
     def update_speed(self, time_passed):
         # Update the speed variables.  ``time_passed`` is the number of
@@ -1536,8 +1794,8 @@ class Mouse(StellarClass):
     def project_cursor(self):
         if (not sge.game.grab_input and self.visible and
                 self.sprite is not None):
-            x = (self.mouse_x / sge.game._xscale) - self.sprite.origin_x
-            y = (self.mouse_y / sge.game._yscale) - self.sprite.origin_y
+            x = (self.mouse_x / sge.game._xscale) - self.image_origin_x
+            y = (self.mouse_y / sge.game._yscale) - self.image_origin_y
             img = self.sprite._get_image(
                 self.image_index, self.image_xscale, self.image_yscale, 
                 self.image_rotation, self.image_alpha, self.image_blend)
@@ -1575,8 +1833,6 @@ class _PygameSprite(pygame.sprite.DirtySprite):
         self.image = pygame.Surface((1, 1))
         self.image.set_colorkey((0, 0, 0))
         self.rect = self.image.get_rect()
-        self.x_offset = 0
-        self.y_offset = 0
 
     def update(self):
         if self.parent() is not None:
@@ -1591,22 +1847,20 @@ class _PygameSprite(pygame.sprite.DirtySprite):
                     self.image = new_image
                     self.dirty = 1
 
-                    w, h = self.image.get_size()
-
-                    nw, nh = parent.sprite._get_image(
-                        parent.image_index, parent.image_xscale,
-                        parent.image_yscale).get_size()
-
-                    self.x_offset, self.y_offset = _get_rotation_offset(
-                        parent.sprite.origin_x, parent.sprite.origin_y,
-                        parent.image_rotation, w, h, nw, nh)
-
-                if self.visible != self.parent().visible:
-                    self.visible = int(self.parent().visible)
+                if self.visible != parent.visible:
+                    self.visible = int(parent.visible)
                     self.dirty = 1
 
+                width = parent._get_image_width()
+                normal_width = parent._get_normal_image_width()
+                height = parent._get_image_height()
+                normal_height = parent._get_normal_image_height()
+                x_offset = (width - normal_width) / 2
+                y_offset = (height - normal_height) / 2
+
                 self.update_rect(parent.x, parent.y, parent.z, parent.sprite,
-                                 parent.image_xscale, parent.image_yscale)
+                                 parent.image_origin_x + x_offset,
+                                 parent.image_origin_y + y_offset)
             else:
                 self.image = pygame.Surface((1, 1))
                 self.image.set_colorkey((0, 0, 0))
@@ -1614,22 +1868,12 @@ class _PygameSprite(pygame.sprite.DirtySprite):
         else:
             self.kill()
 
-    def update_rect(self, x, y, z, sprite, image_xscale, image_yscale):
+    def update_rect(self, x, y, z, sprite, origin_x, origin_y):
         # Update the rect of this Pygame sprite, based on the SGE sprite
         # and coordinates given.  This involves creating "proxy"
         # one-time sprites for multiple views if necessary.
         views = sge.game.current_room.views
 
-        if image_xscale >= 0:
-            origin_x = sprite.origin_x * abs(image_xscale)
-        else:
-            origin_x = (sprite.width - sprite.origin_x) * abs(image_xscale)
-
-        if image_yscale >= 0:
-            origin_y = sprite.origin_y * abs(image_yscale)
-        else:
-            origin_y = (sprite.height - sprite.origin_y) * abs(image_yscale)
-
         if (len(views) == 1 and views[0].xport == 0 and views[0].yport == 0 and
                 views[0].width == sge.game.width and
                 views[0].height == sge.game.height):
@@ -1638,10 +1882,8 @@ class _PygameSprite(pygame.sprite.DirtySprite):
             x = x - views[0].x - origin_x
             y = y - views[0].y - origin_y
             new_rect = self.image.get_rect()
-            new_rect.left = (round(x * sge.game._xscale) - self.x_offset +
-                             sge.game._x)
-            new_rect.top = (round(y * sge.game._yscale) - self.y_offset +
-                            sge.game._y)
+            new_rect.left = round(x * sge.game._xscale) + sge.game._x
+            new_rect.top = round(y * sge.game._yscale) + sge.game._y
 
             if self.rect != new_rect:
                 self.rect = new_rect
@@ -1659,10 +1901,8 @@ class _PygameSprite(pygame.sprite.DirtySprite):
                 w = sprite.width
                 h = sprite.height
                 new_rect = self.image.get_rect()
-                new_rect.left = (round(x * sge.game._xscale) - self.x_offset +
-                                 sge.game._x)
-                new_rect.top = (round(y * sge.game._yscale) - self.y_offset +
-                                sge.game._y)
+                new_rect.left = round(x * sge.game._xscale) + sge.game._x
+                new_rect.top = round(y * sge.game._yscale) + sge.game._y
                 inside_view = (x >= view.xport and
                                x + w <= view.xport + view.width and
                                y >= view.yport and
@@ -1705,10 +1945,8 @@ class _PygameSprite(pygame.sprite.DirtySprite):
                         if y + h > view.yport + view.height:
                             h -= (y + h) - (view.yport + view.height)
 
-                        x = (sge.game._x +
-                             round((x - self.x_offset) * sge.game._xscale))
-                        y = (sge.game._y +
-                             round((y - self.y_offset) * sge.game._yscale))
+                        x = sge.game._x + round(x * sge.game._xscale)
+                        y = sge.game._y + round(y * sge.game._yscale)
                         cut_x *= sge.game._xscale
                         cut_y *= sge.game._yscale
                         w = round(w * sge.game._xscale)
@@ -1740,13 +1978,12 @@ class _PygameProjectionSprite(_PygameSprite):
         self.image_index = image_index
         self.image = sprite._get_image(image_index)
         self.rect = self.image.get_rect()
-        self.x_offset = 0
-        self.y_offset = 0
 
     def update(self):
         if self.dirty:
             self.image = self.sprite._get_image(self.image_index)
-            self.update_rect(self.x, self.y, self.z, self.sprite, 50, 50)
+            self.update_rect(self.x, self.y, self.z, self.sprite,
+                             self.sprite.origin_x, self.sprite.origin_y)
         else:
             self.kill()
 
@@ -1776,33 +2013,3 @@ class _PygameOneTimeSprite(pygame.sprite.DirtySprite):
     def update(self):
         if not self.dirty:
             self.kill()
-
-
-def _get_rotation_offset(origin_x, origin_y, rotation, image_width,
-                         image_height, image_width_normal,
-                         image_height_normal):
-    # Return what to offset an origin when the object is rotated as a
-    # two-part tuple: (x_offset, y_offset)
-    x_offset = 0
-    y_offset = 0
-
-    if rotation % 180:
-        # Adjust offset for the borders getting bigger.
-        x_offset += (image_width - image_width_normal) / 2
-        y_offset += (image_height - image_height_normal) / 2
-
-    if rotation % 360:
-        # Rotate about the origin
-        center_x = image_width_normal / 2
-        center_y = image_height_normal / 2
-        xorig = origin_x - center_x
-        yorig = origin_y - center_y
-        start_angle = math.atan2(-yorig, xorig)
-        radius = math.hypot(xorig, yorig)
-        new_angle = start_angle + math.radians(rotation)
-        new_center_x = origin_x + radius * math.cos(new_angle)
-        new_center_y = origin_y - radius * math.sin(new_angle)
-        x_offset += new_center_x + center_x
-        y_offset += new_center_y + center_y
-
-    return (x_offset, y_offset)
