@@ -340,8 +340,8 @@ along with the Pygame SGE.  If not, see <http://www.gnu.org/licenses/>.
 Dependencies
 ------------
 
-- Python 3.1 or later <http://www.python.org>
-- Pygame 1.9.2 or later <http://pygame.org>
+- Python 2.7 <http://www.python.org>
+- Pygame 1.9.1 or later <http://pygame.org>
 
 Formats Support
 ---------------
@@ -389,9 +389,10 @@ avoid using it; consider using Ogg Vorbis instead.
 Missing Features
 ----------------
 
-:meth:`sge.Sprite.draw_line` and :meth:`sge.Room.project_line` support
-anti-aliasing for lines with a thickness of 1 only.
-:meth:`sge.Sprite.draw_text` and :meth:`sge.Room.project_text` support
+:meth:`sge.Sprite.draw_line`, :meth:`sge.Room.project_line`, and
+:meth:`sge.Game.project_line` support anti-aliasing for lines with a
+thickness of 1 only.  :meth:`sge.Sprite.draw_text`,
+:meth:`sge.Room.project_text`, and :meth:`sge.Game.project_text` support
 anti-aliasing in all cases.  No other drawing or projecting methods
 support anti-aliasing.
 
@@ -410,7 +411,12 @@ by default.
 
 """
 
-__version__ = "0.8.0"
+from __future__ import division
+from __future__ import absolute_import
+from __future__ import print_function
+from __future__ import unicode_literals
+
+__version__ = "0.9.0"
 
 import os
 
@@ -428,6 +434,7 @@ from .StellarClass import StellarClass, Mouse, _PygameProjectionSprite
 from .Room import Room
 from .View import View
 from .functions import *
+from . import collision
 
 
 __all__ = [
